==> react-native-wlc-1.0.23.tgz: package/src/components/molecules/FieldDatePicker.tsx <==
// ImageDatePicker.tsx

import * as React from 'react';
import {useCallback, useState} from 'react';
import {HelperText, Text, useTheme} from 'react-native-paper';
import {DatePickerModal} from 'react-native-paper-dates';
import {useField} from 'formik';
import {TouchableOpacity, View} from 'react-native';
import moment from 'moment';
import {StyleProp} from 'react-native/Libraries/StyleSheet/StyleSheet';
import {ViewStyle} from 'react-native/Libraries/StyleSheet/StyleSheetTypes';
import {CalendarDate} from 'react-native-paper-dates/lib/typescript/Date/Calendar';

export type FieldImageDatePickerProps = {
  name: string;
  placeholder?: string;
  title?: string;
};

export const FieldDatePicker: React.FC<FieldImageDatePickerProps> = ({
  name,
  title,
}) => {
  const [, meta, helpers] = useField(name as any);
  const [visible, setVisible] = useState(false);
  const theme = useTheme();

  const error = meta.touched && meta.error;

  const styles: StyleProp<ViewStyle> = {
    borderWidth: 1,
    borderColor: error ? theme.colors.error : theme.colors.outline,
    padding: 16,
    marginTop: 2,
    borderRadius: 4,
  };

  const handleConfirm = useCallback(
    (date: CalendarDate) => {
      helpers.setValue(moment(date).format());
      setVisible(false);
    },
    [helpers],
  );

  return (
    <React.Fragment>
      {title && <Text variant="labelSmall">{title}</Text>}
      <TouchableOpacity
        onPress={() => {
          helpers.setTouched(true);
          setVisible(true);
        }}>
        <View style={styles}>
          <Text variant={'labelLarge'}>
            {moment.utc(meta.value).format('DD-MMM-YYYY')}
          </Text>
        </View>
      </TouchableOpacity>
      <DatePickerModal
        locale="en"
        mode="single"
        visible={visible}
        onDismiss={() => setVisible(false)}
        date={meta.value ? moment(meta.value).toDate() : undefined}
        onConfirm={d => {
          handleConfirm(d?.date);
        }}
      />
      <HelperText type="error" visible={!!error}>
        {error}
      </HelperText>
    </React.Fragment>
  );
};

==> react-native-wlc-1.0.24.tgz: package/src/components/molecules/FieldDatePicker.tsx <==
// ImageDatePicker

import * as React from "react";
import { useCallback, useState } from "react";
import { HelperText, Text, useTheme } from "react-native-paper";
import { DatePickerModal } from "react-native-paper-dates";
import { useField } from "formik";
import { TouchableOpacity, View } from "react-native";
import moment from "moment";
import { StyleProp } from "react-native/Libraries/StyleSheet/StyleSheet";
import { ViewStyle } from "react-native/Libraries/StyleSheet/StyleSheetTypes";
import { CalendarDate } from "react-native-paper-dates/lib/typescript/Date/Calendar";

export type FieldImageDatePickerProps = {
  name: string;
  placeholder?: string;
  title?: string;
};

export const FieldDatePicker: React.FC<FieldImageDatePickerProps> = ({
  name,
  title,
}) => {
  const [, meta, helpers] = useField(name as any);
  const [visible, setVisible] = useState(false);
  const theme = useTheme();

  const error = meta.touched && meta.error;

  const styles: StyleProp<ViewStyle> = {
    borderWidth: 1,
    borderColor: error ? theme.colors.error : theme.colors.outline,
    padding: 16,
    marginTop: 2,
    borderRadius: 4,
  };

  const handleConfirm = useCallback(
    (date: CalendarDate) => {
      helpers.setValue(moment(date).format());
      setVisible(false);
    },
    [helpers],
  );

  return (
    <React.Fragment>
      {title && <Text variant="labelSmall">{title}</Text>}
      <TouchableOpacity
        onPress={() => {
          helpers.setTouched(true);
          setVisible(true);
        }}
      >
        <View style={styles}>
          <Text variant={"labelLarge"}>
            {moment.utc(meta.value).format("DD-MMM-YYYY")}
          </Text>
        </View>
      </TouchableOpacity>
      <DatePickerModal
        locale="en"
        mode="single"
        visible={visible}
        onDismiss={() => setVisible(false)}
        date={meta.value ? moment(meta.value).toDate() : undefined}
        onConfirm={(d) => {
          handleConfirm(d?.date);
        }}
      />
      <HelperText type="error" visible={!!error}>
        {error}
      </HelperText>
    </React.Fragment>
  );
};
